==> skyfish-0.60.tar.gz: skyfish-0.60/bin/file_sky.h <==
/*-
 * Copyright (c) 2008 Andrey V. Surkov <nsand@sura.ru>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	 $Id: file_sky.h,v 0.52 2008/05/23 07:54:36 nsand Exp $
 */
#ifndef _FILE_SKY_
#define	_FILE_SKY_

#include "my_types.h"
#include "parse_http.h"
#include "db.h"
#include "skyfish.h"

u_long GetRefer(void);
int FileFull(u_long);
//int WriteData(struct ip *ip,struct tcphdr *tcp,u_char *data_tcp);
int	WriteData(u_char *);
int	CheckTime();
int	DelTree(u_long num);
int	GetPerek(u_int64 x, u_int64 y, u_int64 fx, u_int64 fy);
int	ChangeType(u_long refer);
void	DelFile(u_long ref);
void	DelHEAD(u_long ref);
void	Logger(u_char *data);
void	ClearTree(u_long ref);


#define P_LEFT	1
#define P_RIGHT	2
#define P_ALL	3
#define P_IN	4
#define P_NO	5




#endif

==> skyfish-0.91.tar.gz: skyfish-0.91/bin/file_sky.h <==
/*-
 * Copyright (c) 2008 Andrey V. Surkov <nsand@sura.ru>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	 $Id: file_sky.h,v 0.52 2008/05/23 07:54:36 nsand Exp $
 */
#ifndef _FILE_SKY_
#define	_FILE_SKY_

#include "my_types.h"
#include "parse_http.h"
#include "db.h"
#include "skyfish.h"


void	AddFile(const u_long refer);
int	ChangeType(u_long refer);
int	CheckTime(void);
void	ClearTree(u_long ref);
void	CloseFiles(void);
struct crossxy	CrossedFX2(u_long refer,struct crossxy gxy);
int	CheckPaths(void);
void	DelFile(u_long ref);
int 	FileFull(u_long);
int	GetPerek(u_int64_t x, u_int64_t y, u_int64_t fx, u_int64_t fy);
u_long	Getopenfiles(void);
int	WriteData(const char *,u_long numpks,u_long lendata,u_long thseq);
void	Logger(const char *data);
void	MergeFX(u_int64_t x, u_int64_t y, u_long refer);
int	OpenLog(void);
void	SetNocomplete(u_long n);
void	SetPathOk(char *path);
void	SetPathTmp(char *path);
void	SetPathInc(char *path);
void	SetPathLog(char *path);
void	SetTLT(u_long n);
void	SetTFE(u_long n);
void	SetTLB(u_long n);
void	TruncateFX(u_long refer);
int	FillPKS(const u_long refer);
void	TruncateMAX(u_long refer);
void	TruncateEmpty(u_long refer);
void	Incomplete(u_long refer);
int	RegExp(u_long refer);
int	TypeOK(u_long refer);
int 	Ident(char *buffer,const char *search,char *type,u_long refer,u_long len);

#define P_LEFT	1
#define P_RIGHT	2
#define P_ALL	3
#define P_IN	4
#define P_NO	5

#endif
